# -*- coding: utf-8 -*-
# Elisa - Home multimedia server
# Copyright (C) 2006-2008 Fluendo Embedded S.L. (www.fluendo.com).
# All rights reserved.
#
# This file is available under one of two license agreements.
#
# This file is licensed under the GPL version 3.
# See "LICENSE.GPL" in the root of this distribution including a special
# exception to use Elisa with Fluendo's plugins.
#
# The GPL part of Elisa is also available under a commercial licensing
# agreement from Fluendo.
# See "LICENSE.Elisa" in the root directory of this distribution package
# for details on that license.

"""
Create a splash Screen
"""

__maintainer__ = 'Benjamin Kampmann <benjamin@fluendo.com>'

import os
import pkg_resources

LOGO_PATH = pkg_resources.resource_filename('elisa.core', 'data/splash.png')
"""
The path to the splash image to use
"""

try:
    import gtk
    import cairo
except ImportError:
    SplashScreen = None
else:
    class SplashScreen(gtk.Window):
        """
        GTK-Based SplashScreen
        """
        def on_expose(self, win, ev):
            cr = win.window.cairo_create()
            cr.set_operator(cairo.OPERATOR_SOURCE)
            cr.set_source_rgba(1.0, 1.0, 1.0, 0.0)
            cr.paint()
            surface = cairo.ImageSurface.create_from_png(LOGO_PATH)
            cr.set_source_surface (surface)
            cr.paint()

            return True

        def __init__(self, logo_path=LOGO_PATH):
            gtk.Window.__init__(self,gtk.WINDOW_POPUP)

            self.set_decorated(False)
            self.set_position(gtk.WIN_POS_CENTER_ALWAYS)
            try:
                gtk.window_set_auto_startup_notification(False)
            except:
                # Only available in pygtk 2.2 and above, so we don't want
                # to fail if it does not exist
                pass
            self.set_app_paintable(True)

            pixbuf = gtk.gdk.pixbuf_new_from_file(logo_path)
            pixmap, mask = pixbuf.render_pixmap_and_mask()

            width, height = pixmap.get_size()
            self.resize(width, height)

            screen = self.get_screen()
            if screen.is_composited():
                rgba_colormap = screen.get_rgba_colormap()
                self.set_colormap(rgba_colormap)
                self.connect("expose-event", self.on_expose)
            else:
                self.realize()

                self.shape_combine_mask(mask, 0, 0)
                self.window.set_back_pixmap(pixmap, False)

            self.show_all()

